==> jc-1.4.0.tar.gz: polyglot/visit/InitChecker__24InitCount.h <==
// public class polyglot.visit.InitChecker$InitCount

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1c9381815207d149 polyglot_visit_InitChecker__24InitCount

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_InitChecker__24InitCount_H_
#define _JC_polyglot_visit_InitChecker__24InitCount_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_InitChecker__24InitCount$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$sub_refs	_jc_polyglot_visit_InitChecker__24InitCount$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs	_jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$refs	_jc_polyglot_visit_InitChecker__24InitCount$refs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$nonrefs	_jc_polyglot_visit_InitChecker__24InitCount$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$object	_jc_polyglot_visit_InitChecker__24InitCount$object;

typedef struct _jc_polyglot_visit_InitChecker__24InitCount$fields_struct	_jc_polyglot_visit_InitChecker__24InitCount$fields_struct;
typedef const struct _jc_polyglot_visit_InitChecker__24InitCount$vmethods	_jc_polyglot_visit_InitChecker__24InitCount$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24InitCount$vtable	_jc_polyglot_visit_InitChecker__24InitCount$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24InitCount$vtype	_jc_polyglot_visit_InitChecker__24InitCount$vtype;

// Class fields structure
struct _jc_polyglot_visit_InitChecker__24InitCount$fields_struct {
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*MANY;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*ONE;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*ZERO;
};
extern _jc_polyglot_visit_InitChecker__24InitCount$fields_struct _jc_polyglot_visit_InitChecker__24InitCount$class_fields;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24InitCount$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, jint);

// Virtual methods
extern jboolean _jc_polyglot_visit_InitChecker__24InitCount$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24InitCount$method$increment$5e46abb2fbcaeead(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_InitChecker__24InitCount$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_InitChecker__24InitCount$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_InitChecker__24InitCount$method_info$increment$5e46abb2fbcaeead;
extern _jc_method _jc_polyglot_visit_InitChecker__24InitCount$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_visit_InitChecker__24InitCount$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24InitCount$method$max$ed55b9f0f8846618(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24InitCount$method$min$46e67ebca931a33b(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24InitCount$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_java_lang_Object$object *);
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*(*increment$5e46abb2fbcaeead)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *);
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24InitCount$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_InitChecker__24InitCount$vmethods	polyglot_visit_InitChecker__24InitCount;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24InitCount$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24InitCount$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24InitCount$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24InitCount$refs {
    _jc_polyglot_visit_InitChecker__24InitCount$sub_refs	polyglot_visit_InitChecker__24InitCount;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs {
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24InitCount$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs	polyglot_visit_InitChecker__24InitCount;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24InitCount$object {
	_jc_polyglot_visit_InitChecker__24InitCount$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24InitCount$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24InitCount$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24InitCount$vtype _jc_polyglot_visit_InitChecker__24InitCount$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24InitCount, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24InitCount$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24InitCount_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/InitChecker__24InitCount.h <==
// public class polyglot.visit.InitChecker$InitCount

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1c9381815207d149 polyglot_visit_InitChecker__24InitCount

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_InitChecker__24InitCount_H_
#define _JC_polyglot_visit_InitChecker__24InitCount_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_InitChecker__24InitCount$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$sub_refs	_jc_polyglot_visit_InitChecker__24InitCount$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs	_jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$refs	_jc_polyglot_visit_InitChecker__24InitCount$refs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$nonrefs	_jc_polyglot_visit_InitChecker__24InitCount$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24InitCount$object	_jc_polyglot_visit_InitChecker__24InitCount$object;

typedef struct _jc_polyglot_visit_InitChecker__24InitCount$fields_struct	_jc_polyglot_visit_InitChecker__24InitCount$fields_struct;
typedef const struct _jc_polyglot_visit_InitChecker__24InitCount$vmethods	_jc_polyglot_visit_InitChecker__24InitCount$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24InitCount$vtable	_jc_polyglot_visit_InitChecker__24InitCount$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24InitCount$vtype	_jc_polyglot_visit_InitChecker__24InitCount$vtype;

// Class fields structure
struct _jc_polyglot_visit_InitChecker__24InitCount$fields_struct {
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*MANY;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*ONE;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*ZERO;
};
extern _jc_polyglot_visit_InitChecker__24InitCount$fields_struct _jc_polyglot_visit_InitChecker__24InitCount$class_fields;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24InitCount$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_InitChecker__24InitCount$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24InitCount$method$increment$5e46abb2fbcaeead(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_InitChecker__24InitCount$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_InitChecker__24InitCount$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_InitChecker__24InitCount$method_info$increment$5e46abb2fbcaeead;
extern _jc_method _jc_polyglot_visit_InitChecker__24InitCount$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_visit_InitChecker__24InitCount$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24InitCount$method$max$ed55b9f0f8846618(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_InitChecker__24InitCount$object *_jc_polyglot_visit_InitChecker__24InitCount$method$min$46e67ebca931a33b(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24InitCount$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_InitChecker__24InitCount$object	*(*increment$5e46abb2fbcaeead)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24InitCount$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24InitCount$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_InitChecker__24InitCount$vmethods	polyglot_visit_InitChecker__24InitCount;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24InitCount$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24InitCount$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24InitCount$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24InitCount$refs {
    _jc_polyglot_visit_InitChecker__24InitCount$sub_refs	polyglot_visit_InitChecker__24InitCount;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs {
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24InitCount$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_InitChecker__24InitCount$sub_nonrefs	polyglot_visit_InitChecker__24InitCount;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24InitCount$object {
	_jc_polyglot_visit_InitChecker__24InitCount$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24InitCount$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24InitCount$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24InitCount$vtype _jc_polyglot_visit_InitChecker__24InitCount$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24InitCount, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24InitCount$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24InitCount_H_ */
